@@ -21,7 +21,7 @@ has '+name' => (
     default => 'md5',
 );
 
-has '_digest_md5' => (
+has '_digest' => (
     is => 'ro',
     lazy => 1,
     builder => '_build_digest_md5',
@@ -41,9 +41,9 @@ sub get_hash_string {
         = stat $fh;
     my $buffer;
     while (read($fh, $buffer, $blksize)) {
-        $self->_digest_md5->add($buffer);
+        $self->_digest->add($buffer);
     }
-    return $self->_digest_md5->hexdigest;
+    return $self->_digest->hexdigest;
 
 }
 
@@ -70,7 +70,7 @@ Archive::BagIt::Plugin::Algorithm::MD5 - The default MD5 algorithm plugin
 
 =head1 VERSION
 
-version 0.058
+version 0.059
 
 =head1 NAME
 
@@ -78,7 +78,7 @@ Archive::BagIt::Plugin::Algorithm::MD5 - The default MD5 algorithm plugin
 
 =head1 VERSION
 
-version 0.058
+version 0.059
 
 =head1 AVAILABILITY
 
